==> haskell-bin-0.1.2-19-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 bin
version:              0.1.2
visibility:           public
id:                   bin-0.1.2-FaeHQFjJPbWFTRSsMWjVGn
key:                  bin-0.1.2-FaeHQFjJPbWFTRSsMWjVGn
license:              GPL-2.0-or-later
copyright:            (c) 2019-2021 Oleg Grenrus
maintainer:           Oleg.Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/vec
synopsis:             Bin: binary natural numbers.
description:
    This package provides /binary natural numbers/ ("Data.Bin");
    also utilities to work on the type level with @DataKinds@ ("Data.Type.Bin").

    @
    data Bin
    \    = BZ       -- ^ zero
    \    | BP BinP  -- ^ non-zero

    data BinP
    \    = BE       -- ^ one
    \    | B0 BinP  -- ^ double
    \    | B1 BinP  -- ^ double plus 1
    @

    There are /ordinals/ in "Data.Bin.Pos" module, as well as
    fixed width integers in "Data.Wrd".

    Another implementation is at <https://hackage.haskell.org/package/nat>,
    this differs in naming, and provides promoted variant.

category:             Data, Dependent Types, Singletons, Math
abi:                  8e34bc36c6a5dc76cdc3141feb7451a6
exposed:              True
exposed-modules:
    Data.Bin Data.Bin.Pos Data.BinP Data.BinP.PosP Data.Type.Bin
    Data.Type.BinP Data.Wrd

hidden-modules:       TrustworthyCompat
import-dirs:          /usr/lib/ghc-9.0.2/site-local/bin-0.1.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/bin-0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bin
hs-libraries:         HSbin-0.1.2-FaeHQFjJPbWFTRSsMWjVGn
depends:
    QuickCheck-2.14.2-IrKCsUZGhGU1PtqQldQ5rR base-4.15.1.0
    boring-0.2-AywtoMK07vg9Z9Ocyuk3Wm dec-0.0.4-6eP3x413uTPG9dUJ2u492R
    deepseq-1.4.5.0 fin-0.2.1-LZb7Noqbr4sAATqwSOck6k
    hashable-1.4.0.1-BTNvM8tfYS9gMn15aJ88A
    some-1.0.3-4tJBwqdl6II5ViVY4feiYl

haddock-interfaces:   /usr/share/doc/haskell-bin/html/bin.haddock
haddock-html:         /usr/share/doc/haskell-bin/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bin-0.1.2-21-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 bin
version:              0.1.2
visibility:           public
id:                   bin-0.1.2-EYaREPnopwl4EKGj556IYd
key:                  bin-0.1.2-EYaREPnopwl4EKGj556IYd
license:              GPL-2.0-or-later
copyright:            (c) 2019-2021 Oleg Grenrus
maintainer:           Oleg.Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/vec
synopsis:             Bin: binary natural numbers.
description:
    This package provides /binary natural numbers/ ("Data.Bin");
    also utilities to work on the type level with @DataKinds@ ("Data.Type.Bin").

    @
    data Bin
    \    = BZ       -- ^ zero
    \    | BP BinP  -- ^ non-zero

    data BinP
    \    = BE       -- ^ one
    \    | B0 BinP  -- ^ double
    \    | B1 BinP  -- ^ double plus 1
    @

    There are /ordinals/ in "Data.Bin.Pos" module, as well as
    fixed width integers in "Data.Wrd".

    Another implementation is at <https://hackage.haskell.org/package/nat>,
    this differs in naming, and provides promoted variant.

category:             Data, Dependent Types, Singletons, Math
abi:                  6e0bb6ebb690a5fc721acab8ece82cdd
exposed:              True
exposed-modules:
    Data.Bin Data.Bin.Pos Data.BinP Data.BinP.PosP Data.Type.Bin
    Data.Type.BinP Data.Wrd

hidden-modules:       TrustworthyCompat
import-dirs:          /usr/lib/ghc-9.0.2/site-local/bin-0.1.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/bin-0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bin
hs-libraries:         HSbin-0.1.2-EYaREPnopwl4EKGj556IYd
depends:
    QuickCheck-2.14.2-CKku5U4XaTZ1OrrQj3RQZM base-4.15.1.0
    boring-0.2-AywtoMK07vg9Z9Ocyuk3Wm dec-0.0.4-6eP3x413uTPG9dUJ2u492R
    deepseq-1.4.5.0 fin-0.2.1-47XkfgtwwmW4wbvLXHT0FZ
    hashable-1.4.0.2-A7cEvE0oiq92I0kqqbT0NC
    some-1.0.3-4tJBwqdl6II5ViVY4feiYl

haddock-interfaces:   /usr/share/doc/haskell-bin/html/bin.haddock
haddock-html:         /usr/share/doc/haskell-bin/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
